/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "init.h"

/**
 * Initializes the pws library. Must be called before
 * using any other pwslib functions.
 *
 * @param gry_sec_mem  - libgcrypt secure memory to be initialized in megabytes.
 */
void init_pws_lib (int grcy_sec_mem)
{
    if (!gcry_check_version("1.0.0")) // hm, just a guess
    {
        printf ("libgcrypt > 1.0.0 needed\n");
        exit (1);
    }

    gcry_control (GCRYCTL_INIT_SECMEM, grcy_sec_mem*1024*1024, 0);

#ifdef HAVE_MLOCKALL
    if (mlockall (MCL_CURRENT|MCL_FUTURE) == -1)
        { fprintf (stderr, "libpws - mlockall() failed, using insecure memory\n"); }
#endif
    register_sha1_init_state_zero ();
}

/**
 * Releases the pwslib.
 */
void release_pws_lib ()
{
    gcry_control (GCRYCTL_DROP_PRIVS);
    gcry_control (GCRYCTL_TERM_SECMEM);
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
